"use strict";

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLogger = getLogger;
exports.initLogger = initLogger;

var _winston = _interopRequireWildcard(require("winston"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var logger;
var loggerLevelsInfo = {
  levels: {
    err: 0,
    info: 1,
    dbg: 2
  },
  colors: {
    err: 'brightRed',
    info: 'brightBlue',
    dbg: 'gray'
  }
};

var colorizer = _winston["default"].format.colorize();

function initLogger(level) {
  if (logger != null) {
    throw new Error('Logger has been already initialized');
  }

  var baseLogger = _winston["default"].createLogger({
    levels: loggerLevelsInfo.levels,
    level: level,
    format: _winston.format.combine(_winston.format.timestamp({
      format: 'YYYY-MM-DD hh:mm:ss.SSS'
    }), _winston.format.align(), _winston.format.printf(function (info) {
      return colorizer.colorize(info.level, "".concat(info.timestamp, " ").concat(info.level, ": ").concat(info.message));
    })),
    transports: [new _winston["default"].transports.Console()]
  });

  _winston["default"].addColors(loggerLevelsInfo.colors);

  logger = {
    err: function err(message) {
      baseLogger.log('err', message);
    },
    info: function info(message) {
      baseLogger.log('info', message);
    },
    dbg: function dbg(message) {
      baseLogger.log('dbg', message);
    },
    logger: baseLogger
  };
}

function getLogger() {
  if (logger == null) {
    throw new Error('Attempt to use not initialized Logger');
  }

  return logger;
}
//# sourceMappingURL=logger.js.map